Front Matter — dogpile.cache 0.7.1 documentation

# Front Matter

Information about the dogpile.cache project.

## Project Homepage

dogpile.cache is hosted on GitHub at https://github.com/sqlalchemy/dogpile.cache.

Releases and project status are available on Pypi at https://pypi.python.org/pypi/dogpile.cache.

The most recent published version of this documentation should be at https://dogpilecache.sqlalchemy.org.

## Installation

Install released versions of dogpile.cache from the Python package index with pip or a similar tool:

    pip install dogpile.cache

## Bugs

Bugs and feature enhancements to dogpile.cache should be reported on the GitHub issue tracker.